%Formats and displays the results of the one-time pad encryption/decryption
%demo
%
%Input:
% input_data     - The input data (char array)
% encrypted_data - The encrypted data (byte array)
% decrypted_data - The decrypted data (byte array)
% key            - The encryption key (byte array)
function display_one_time_pad_results(input_data,encrypted_data,decrypted_data,key)
    max_bytes_to_display = 30;
    
    %Repeat the encryption key up to the length of the input data
    [m,n] = size(input_data);
    padded_key = uint8(key(mod(0:n-1,numel(key))+1));
    
    %Generate a bit matrix of the variables
    %Each row is a byte
    bit_input_data = de2bi(input_data,8,'left-msb');
    bit_encrypted_data = de2bi(encrypted_data,8,'left-msb');
    bit_decrypted_data = de2bi(decrypted_data,8,'left-msb');
    bit_padded_key = de2bi(padded_key,8,'left-msb');
    bit_key = de2bi(key,8,'left-msb');
    
    %Generate the char array for the key in binary
    [m,n] = size(bit_key);
    key_display = 'Pad       :';
    for i = 1:m
        %Add a space between the bytes
        key_display = [key_display ' '];
        %Append the next byte in binary
        for j = 1:8
            key_display = [key_display int2str(bit_key(i,j))];
        end
    end
    
    %Initialize the output char arrays
    input_display      = 'Message   :';
    padded_key_display = 'Padded key:';
    encrypt_display    = 'CipherText:';
    decrypt_display    = 'Decrypted :';
    
    %Truncate long display data
    [m,n] = size(bit_input_data);
    if(m > max_bytes_to_display)
        m = max_bytes_to_display;
    end
    %Generat the data portion of the output char arrays
    for i = 1:m
        %Add a space between the bytes
        input_display = [input_display ' '];
        padded_key_display = [padded_key_display ' '];
        encrypt_display = [encrypt_display ' '];
        decrypt_display = [decrypt_display ' '];
        %Append the next byte in binary
        for j = 1:8
            input_display = [input_display int2str(bit_input_data(i,j))];
            padded_key_display = [padded_key_display int2str(bit_padded_key(i,j))];
            encrypt_display = [encrypt_display int2str(bit_encrypted_data(i,j))];
            decrypt_display = [decrypt_display int2str(bit_decrypted_data(i,j))];
        end
    end
    
    %Display the encryption key in binary
    fprintf('%i-bit Encryption key:\n',length(key)*8);
    disp(key_display);
    
    %Display the results of the encryption process
    fprintf('\nEncryption Results:\n');
    disp(input_display);
    disp(padded_key_display);
    disp(encrypt_display);
    
    %Display the results of the decryption process
    fprintf('\nDecryption Results:\n');
    disp(encrypt_display);
    disp(padded_key_display);
    disp(decrypt_display);
    
    %Compare the input data vs the decrypted data
    fprintf('\nComparison of input and decrypted data:\n');
    disp([input_display;decrypt_display]);
end