%Decrypts a byte array using One-time pad decryption with the provided key
%
%Input:
% encrypted_data - Byte array reprsenting the encrypted data (byte array)
% key            - Key to encrypt the data with (byte array)
%
%Output:
% decrypted_data      - The resulting decrypted data (byte array)
% decrypted_data_char - The resulting decrypted data (char array)
function [decrypted_data,decrypted_data_char] = one_time_pad_decrypt(encrypted_data,key)
    %Generate an equivalent array of the key repating up the the length of
    %the data array.
    %This subsitutes the process of performing XOR of each of the n-bit
    %segments of the input data with the n-bit key
    [m,n] = size(encrypted_data);
    padded_key = uint8(key(mod(0:n-1,numel(key))+1));
    
    %Performs an XOR operation with the key and encrypted data
    decrypted_data = uint8(bitxor(padded_key,encrypted_data));
    
    %Alternative way of decrypting data in n-bit blocks
    %Performs XOR for each n-bit block of data
%     [m,n] = size(encrypted_data);
%     [m1,n1] = size(key);
%     decrypted_data = zeros(1,m);
%     for i = 1:ceil(n/n1)
%         if(n-(i-1)*n1 >= n1)
%             temp_key = key;
%         else
%             temp_key = key(1,1:(n-(i-1)*n1));
%         end
%         decrypted_data(1,((i-1)*n1+1):(i-1)*n1+length(temp_key)) = bitxor(encrypted_data(1,((i-1)*n1+1):(i-1)*n1+length(temp_key)),temp_key);
%     end
    
    %Converts the resulting decrypted data to a char array.
    decrypted_data_char = char(decrypted_data);
end