%Encrypts a char array using One-time pad encryption with the provided key
%
%Input:
% input_data - Char array reprsenting the input data (char array)
% key        - Key to encrypt the data with (byte array)
%
%Output:
% encrypted_data      - The resulting encrypted data (byte array)
% encrypted_data_char - The resulting encrypted data (char array)
function [encrypted_data,encrypted_data_char] = one_time_pad_encrypt(input_data,key)   
    %Generate an equivalent array of the key repating up the the length of
    %the data array.
    %This subsitutes the process of performing XOR of each of the n-bit
    %segments of the input data with the n-bit key
    [m,n] = size(input_data);
    padded_key = uint8(key(mod(0:n-1,numel(key))+1));
    
    %Performs an XOR operation with the key and input data
    encrypted_data = uint8(bitxor(padded_key,input_data));
    
    %Alternative way of encrypting data in n-bit blocks of data
    %Performs XOR for each n-bit block of data
%     [m,n] = size(input_data);
%     [m1,n1] = size(key);
%     encrypted_data = zeros(1,m);
%     for i = 1:ceil(n/n1)
%         if(n-(i-1)*n1 >= n1)
%             temp_key = key;
%         else
%             temp_key = key(1,1:(n-(i-1)*n1));
%         end
%         encrypted_data(1,((i-1)*n1+1):(i-1)*n1+length(temp_key)) = bitxor(input_data(1,((i-1)*n1+1):(i-1)*n1+length(temp_key)),temp_key);
%     end
    
    %Converts the resulting array to a char array.
    encrypted_data_char = char(encrypted_data);
end